BytesCount

Struct BytesCount 

pub struct BytesCount { /* private fields */ }
Process N bytes.

Implementations

Source

impl BytesCount

pub fn new<N: CountUInt>(count: N) -> Self

Count N bytes.

pub const fn of<T>() -> Self

Counts the size of a type with size_of.

pub const fn of_many<T>(n: usize) -> Self

Counts the size of multiple instances of a type with size_of.

pub fn of_val<T: ?Sized>(val: &T) -> Self

Counts the size of a value with size_of_val.

pub fn of_iter<T, I>(iter: I) -> Self
where I: IntoIterator<Item = T>,

Counts the bytes of Iterator::Items.

pub fn of_str<S: ?Sized + AsRef<str>>(s: &S) -> Self

Counts the bytes of a &str.

This is like BytesCount::of_val with the convenience of behaving as expected for &String and other types that convert to &str.

pub fn of_slice<T, S: ?Sized + AsRef<[T]>>(s: &S) -> Self

Counts the bytes of a slice.

This is like BytesCount::of_val with the convenience of behaving as expected for &Vec<T> and other types that convert to &[T].

Source

impl BytesCount

Count bytes of multiple values.

pub const fn f32(n: usize) -> Self

Counts the bytes of multiple f32s.

pub const fn f64(n: usize) -> Self

Counts the bytes of multiple f64s.

pub const fn i8(n: usize) -> Self

Counts the bytes of multiple i8s.

pub const fn u8(n: usize) -> Self

Counts the bytes of multiple u8s.

pub const fn i16(n: usize) -> Self

Counts the bytes of multiple i16s.

pub const fn u16(n: usize) -> Self

Counts the bytes of multiple u16s.

pub const fn i32(n: usize) -> Self

Counts the bytes of multiple i32s.

pub const fn u32(n: usize) -> Self

Counts the bytes of multiple u32s.

pub const fn i64(n: usize) -> Self

Counts the bytes of multiple i64s.

pub const fn u64(n: usize) -> Self

Counts the bytes of multiple u64s.

pub const fn i128(n: usize) -> Self

Counts the bytes of multiple i128s.

pub const fn u128(n: usize) -> Self

Counts the bytes of multiple u128s.

pub const fn isize(n: usize) -> Self

Counts the bytes of multiple isizes.

pub const fn usize(n: usize) -> Self

Counts the bytes of multiple usizes.